@@ -8,6 +8,7 @@ from agno.db.base import AsyncBaseDb, BaseDb
 from agno.db.schemas.culture import CulturalKnowledge
 from agno.models.base import Model
 from agno.models.message import Message
+from agno.models.utils import get_model
 from agno.tools.function import Function
 from agno.utils.log import (
     log_debug,
@@ -55,7 +56,7 @@ class CultureManager:
 
     def __init__(
         self,
-        model: Optional[Model] = None,
+        model: Optional[Union[Model, str]] = None,
         db: Optional[Union[BaseDb, AsyncBaseDb]] = None,
         system_message: Optional[str] = None,
         culture_capture_instructions: Optional[str] = None,
@@ -66,9 +67,7 @@ class CultureManager:
         clear_knowledge: bool = True,
         debug_mode: bool = False,
     ):
-        self.model = model
-        if self.model is not None and isinstance(self.model, str):
-            raise ValueError("Model must be a Model object, not a string")
+        self.model = get_model(model)
         self.db = db
         self.system_message = system_message
         self.culture_capture_instructions = culture_capture_instructions
@@ -78,8 +77,6 @@ class CultureManager:
         self.delete_knowledge = delete_knowledge
         self.clear_knowledge = clear_knowledge
         self.debug_mode = debug_mode
-        self._tools_for_model: Optional[List[Dict[str, Any]]] = None
-        self._functions_for_model: Optional[Dict[str, Function]] = None
 
     def get_model(self) -> Model:
         if self.model is None:
@@ -137,9 +134,10 @@ class CultureManager:
         if not self.db:
             return None
 
-        self.db = cast(AsyncBaseDb, self.db)
-
-        return await self.db.get_all_cultural_knowledge(name=name)
+        if isinstance(self.db, AsyncBaseDb):
+            return await self.db.get_all_cultural_knowledge(name=name)
+        else:
+            return self.db.get_all_cultural_knowledge(name=name)
 
     def add_cultural_knowledge(
         self,
@@ -233,7 +231,11 @@ class CultureManager:
         if not messages or not isinstance(messages, list):
             raise ValueError("Invalid messages list")
 
-        knowledge = self.get_all_knowledge()
+        if isinstance(self.db, AsyncBaseDb):
+            knowledge = await self.aget_all_knowledge()
+        else:
+            knowledge = self.get_all_knowledge()
+
         if knowledge is None:
             knowledge = []
 
@@ -316,23 +318,27 @@ class CultureManager:
         return response
 
     # -*- Utility Functions -*-
-    def _determine_tools_for_model(self, tools: List[Callable]) -> None:
+    def _determine_tools_for_model(self, tools: List[Callable]) -> List[Union[Function, dict]]:
         # Have to reset each time, because of different user IDs
-        self._tools_for_model = []
-        self._functions_for_model = {}
+
+        _function_names = []
+        _functions: List[Union[Function, dict]] = []
 
         for tool in tools:
             try:
                 function_name = tool.__name__
-                if function_name not in self._functions_for_model:
-                    func = Function.from_callable(tool, strict=True)  # type: ignore
-                    func.strict = True
-                    self._functions_for_model[func.name] = func
-                    self._tools_for_model.append({"type": "function", "function": func.to_dict()})
-                    log_debug(f"Added function {func.name}")
+                if function_name in _function_names:
+                    continue
+                _function_names.append(function_name)
+                func = Function.from_callable(tool, strict=True)  # type: ignore
+                func.strict = True
+                _functions.append(func)
+                log_debug(f"Added function {func.name}")
             except Exception as e:
                 log_warning(f"Could not add function {tool}: {e}")
 
+        return _functions
+
     def get_system_message(
         self,
         existing_knowledge: Optional[List[Dict[str, Any]]] = None,
@@ -460,7 +466,7 @@ class CultureManager:
 
         model_copy = deepcopy(self.model)
         # Update the Model (set defaults, add logit etc.)
-        self._determine_tools_for_model(
+        _tools = self._determine_tools_for_model(
             self._get_db_tools(
                 db,
                 enable_add_knowledge=add_knowledge,
@@ -485,8 +491,7 @@ class CultureManager:
         # Generate a response from the Model (includes running function calls)
         response = model_copy.response(
             messages=messages_for_model,
-            tools=self._tools_for_model,
-            functions=self._functions_for_model,
+            tools=_tools,
         )
 
         if response.tool_calls is not None and len(response.tool_calls) > 0:
@@ -513,7 +518,7 @@ class CultureManager:
         model_copy = deepcopy(self.model)
         db = cast(AsyncBaseDb, db)
 
-        self._determine_tools_for_model(
+        _tools = self._determine_tools_for_model(
             await self._aget_db_tools(
                 db,
                 enable_update_knowledge=update_knowledge,
@@ -535,8 +540,7 @@ class CultureManager:
         # Generate a response from the Model (includes running function calls)
         response = await model_copy.aresponse(
             messages=messages_for_model,
-            tools=self._tools_for_model,
-            functions=self._functions_for_model,
+            tools=_tools,
         )
 
         if response.tool_calls is not None and len(response.tool_calls) > 0:
@@ -564,7 +568,7 @@ class CultureManager:
 
         model_copy = deepcopy(self.model)
         # Update the Model (set defaults, add logit etc.)
-        self._determine_tools_for_model(
+        _tools = self._determine_tools_for_model(
             self._get_db_tools(
                 db,
                 enable_delete_knowledge=delete_knowledge,
@@ -590,8 +594,7 @@ class CultureManager:
         # Generate a response from the Model (includes running function calls)
         response = model_copy.response(
             messages=messages_for_model,
-            tools=self._tools_for_model,
-            functions=self._functions_for_model,
+            tools=_tools,
         )
 
         if response.tool_calls is not None and len(response.tool_calls) > 0:
@@ -620,7 +623,7 @@ class CultureManager:
         model_copy = deepcopy(self.model)
         # Update the Model (set defaults, add logit etc.)
         if isinstance(db, AsyncBaseDb):
-            self._determine_tools_for_model(
+            _tools = self._determine_tools_for_model(
                 await self._aget_db_tools(
                     db,
                     enable_delete_knowledge=delete_knowledge,
@@ -630,7 +633,7 @@ class CultureManager:
                 ),
             )
         else:
-            self._determine_tools_for_model(
+            _tools = self._determine_tools_for_model(
                 self._get_db_tools(
                     db,
                     enable_delete_knowledge=delete_knowledge,
@@ -656,8 +659,7 @@ class CultureManager:
         # Generate a response from the Model (includes running function calls)
         response = await model_copy.aresponse(
             messages=messages_for_model,
-            tools=self._tools_for_model,
-            functions=self._functions_for_model,
+            tools=_tools,
         )
 
         if response.tool_calls is not None and len(response.tool_calls) > 0:
