@@ -1,4 +1,4 @@
-from agno.db.async_postgres import AsyncPostgresDb
+from agno.db.postgres.async_postgres import AsyncPostgresDb
 from agno.db.postgres.postgres import PostgresDb
 
 __all__ = ["PostgresDb", "AsyncPostgresDb"]
