@@ -1,4 +1,3 @@
-from base64 import b64encode
 from io import BytesIO
 from os import getenv, path
 from pathlib import Path
@@ -10,7 +9,7 @@ from agno.media import Audio
 from agno.team.team import Team
 from agno.tools import Toolkit
 from agno.tools.function import ToolResult
-from agno.utils.log import logger
+from agno.utils.log import log_error, log_info
 
 try:
     from elevenlabs import ElevenLabs  # type: ignore
@@ -48,7 +47,7 @@ class ElevenLabsTools(Toolkit):
     ):
         self.api_key = api_key or getenv("ELEVEN_LABS_API_KEY")
         if not self.api_key:
-            logger.error("ELEVEN_LABS_API_KEY not set. Please set the ELEVEN_LABS_API_KEY environment variable.")
+            log_error("ELEVEN_LABS_API_KEY not set. Please set the ELEVEN_LABS_API_KEY environment variable.")
 
         self.target_directory = target_directory
         self.voice_id = voice_id
@@ -73,7 +72,7 @@ class ElevenLabsTools(Toolkit):
 
     def get_voices(self) -> str:
         """
-        Use this function to get all the voices available.
+        Get all the voices available.
 
         Returns:
             result (list): A list of voices that have an ID, name and description.
@@ -94,20 +93,19 @@ class ElevenLabsTools(Toolkit):
             return str(response)
 
         except Exception as e:
-            logger.error(f"Failed to fetch voices: {e}")
+            log_error(f"Failed to fetch voices: {e}")
             return f"Error: {e}"
 
-    def _process_audio(self, audio_generator: Iterator[bytes]) -> str:
-        # Step 1: Write audio data to BytesIO
+    def _process_audio(self, audio_generator: Iterator[bytes]) -> bytes:
         audio_bytes = BytesIO()
         for chunk in audio_generator:
             audio_bytes.write(chunk)
-        audio_bytes.seek(0)  # Rewind the stream
 
-        # Step 2: Encode as Base64
-        base64_audio = b64encode(audio_bytes.read()).decode("utf-8")
+        # Read bytes
+        audio_bytes.seek(0)
+        audio_data = audio_bytes.read()
 
-        # Step 3: Optionally save to disk if target_directory exists
+        # Save to disk if target_directory exists
         if self.target_directory:
             # Determine file extension based on output format
             if self.output_format.startswith("mp3"):
@@ -122,19 +120,19 @@ class ElevenLabsTools(Toolkit):
             output_filename = f"{uuid4()}.{extension}"
             output_path = path.join(self.target_directory, output_filename)
 
-            # Write from BytesIO to disk
-            audio_bytes.seek(0)  # Reset the BytesIO stream again
             with open(output_path, "wb") as f:
-                f.write(audio_bytes.read())
+                f.write(audio_data)
 
-        return base64_audio
+            log_info(f"Audio saved to: {output_path}")
+
+        return audio_data
 
     def generate_sound_effect(self, prompt: str, duration_seconds: Optional[float] = None) -> ToolResult:
         """
-        Use this function to generate sound effect audio from a text prompt.
+        Generate a sound effect from a text description.
 
         Args:
-            prompt (str): Text to generate audio from.
+            prompt (str): Description of the sound effect
             duration_seconds (Optional[float]): Duration in seconds to generate audio from. Has to be between 0.5 and 22.
         Returns:
             ToolResult: A ToolResult containing the generated audio or error message.
@@ -144,27 +142,27 @@ class ElevenLabsTools(Toolkit):
                 text=prompt, duration_seconds=duration_seconds
             )
 
-            base64_audio = self._process_audio(audio_generator)
+            audio_data = self._process_audio(audio_generator)
 
             # Create AudioArtifact
             audio_artifact = Audio(
                 id=str(uuid4()),
-                base64_audio=base64_audio,
+                content=audio_data,
                 mime_type="audio/mpeg",
             )
 
             return ToolResult(
-                content="Audio generated successfully",
+                content="Sound effect generated successfully",
                 audios=[audio_artifact],
             )
 
         except Exception as e:
-            logger.error(f"Failed to generate audio: {e}")
+            log_error(f"Failed to generate sound effect: {e}")
             return ToolResult(content=f"Error: {e}")
 
     def text_to_speech(self, agent: Union[Agent, Team], prompt: str) -> ToolResult:
         """
-        Use this function to convert text to speech audio.
+        Convert text to speech.
 
         Args:
             prompt (str): Text to generate audio from.
@@ -179,12 +177,12 @@ class ElevenLabsTools(Toolkit):
                 output_format=self.output_format,
             )
 
-            base64_audio = self._process_audio(audio_generator)
+            audio_data = self._process_audio(audio_generator)
 
             # Create AudioArtifact
             audio_artifact = Audio(
                 id=str(uuid4()),
-                base64_audio=base64_audio,
+                content=audio_data,
                 mime_type="audio/mpeg",
             )
 
@@ -194,5 +192,5 @@ class ElevenLabsTools(Toolkit):
             )
 
         except Exception as e:
-            logger.error(f"Failed to generate audio: {e}")
+            log_error(f"Failed to generate audio: {e}")
             return ToolResult(content=f"Error: {e}")
