@@ -25,9 +25,10 @@ class SQLTools(Toolkit):
         schema: Optional[str] = None,
         dialect: Optional[str] = None,
         tables: Optional[Dict[str, Any]] = None,
-        list_tables: bool = True,
-        describe_table: bool = True,
-        run_sql_query: bool = True,
+        enable_list_tables: bool = True,
+        enable_describe_table: bool = True,
+        enable_run_sql_query: bool = True,
+        all: bool = False,
         **kwargs,
     ):
         # Get the database engine
@@ -53,11 +54,11 @@ class SQLTools(Toolkit):
         self.tables: Optional[Dict[str, Any]] = tables
 
         tools: List[Any] = []
-        if list_tables:
+        if enable_list_tables or all:
             tools.append(self.list_tables)
-        if describe_table:
+        if enable_describe_table or all:
             tools.append(self.describe_table)
-        if run_sql_query:
+        if enable_run_sql_query or all:
             tools.append(self.run_sql_query)
 
         super().__init__(name="sql_tools", tools=tools, **kwargs)
