@@ -7,7 +7,7 @@ from rich.markdown import Markdown
 from rich.status import Status
 from rich.text import Text
 
-from agno.media import Audio, Image, Video
+from agno.media import Audio, File, Image, Video
 from agno.models.message import Message
 from agno.run.workflow import (
     ConditionExecutionCompletedEvent,
@@ -25,6 +25,8 @@ from agno.run.workflow import (
     StepsExecutionCompletedEvent,
     StepsExecutionStartedEvent,
     StepStartedEvent,
+    WorkflowAgentCompletedEvent,
+    WorkflowAgentStartedEvent,
     WorkflowCompletedEvent,
     WorkflowErrorEvent,
     WorkflowRunOutput,
@@ -48,6 +50,7 @@ def print_response(
     audio: Optional[List[Audio]] = None,
     images: Optional[List[Image]] = None,
     videos: Optional[List[Video]] = None,
+    files: Optional[List[File]] = None,
     markdown: bool = True,
     show_time: bool = True,
     show_step_details: bool = True,
@@ -76,6 +79,8 @@ def print_response(
         media_info.append(f"Images: {len(images)}")
     if videos:
         media_info.append(f"Videos: {len(videos)}")
+    if files:
+        media_info.append(f"Files: {len(files)}")
 
     workflow_info = f"""**Workflow:** {workflow.name}"""
     if workflow.description:
@@ -126,12 +131,22 @@ def print_response(
                 audio=audio,
                 images=images,
                 videos=videos,
+                files=files,
                 **kwargs,
             )  # type: ignore
 
             response_timer.stop()
 
-            if show_step_details and workflow_response.step_results:
+            # Check if this is a workflow agent direct response
+            if workflow_response.workflow_agent_run is not None and not workflow_response.workflow_agent_run.tools:
+                # Agent answered directly from history without executing workflow
+                agent_response_panel = create_panel(
+                    content=Markdown(str(workflow_response.content)) if markdown else str(workflow_response.content),
+                    title="Workflow Agent Response",
+                    border_style="green",
+                )
+                console.print(agent_response_panel)  # type: ignore
+            elif show_step_details and workflow_response.step_results:
                 for i, step_output in enumerate(workflow_response.step_results):
                     print_step_output_recursive(step_output, i + 1, markdown, console)  # type: ignore
 
@@ -186,6 +201,7 @@ def print_response_stream(
     audio: Optional[List[Audio]] = None,
     images: Optional[List[Image]] = None,
     videos: Optional[List[Video]] = None,
+    files: Optional[List[File]] = None,
     stream_events: bool = False,
     stream_intermediate_steps: bool = False,
     markdown: bool = True,
@@ -210,6 +226,8 @@ def print_response_stream(
         media_info.append(f"Images: {len(images)}")
     if videos:
         media_info.append(f"Videos: {len(videos)}")
+    if files:
+        media_info.append(f"Files: {len(files)}")
 
     workflow_info = f"""**Workflow:** {workflow.name}"""
     if workflow.description:
@@ -253,6 +271,8 @@ def print_response_stream(
     step_results = []
     step_started_printed = False
     is_callable_function = callable(workflow.steps)
+    workflow_started = False  # Track if workflow has actually started
+    is_workflow_agent_response = False  # Track if this is a workflow agent direct response
 
     # Smart step hierarchy tracking
     current_primitive_context = None  # Current primitive being executed (parallel, loop, etc.)
@@ -314,18 +334,32 @@ def print_response_stream(
                 audio=audio,
                 images=images,
                 videos=videos,
+                files=files,
                 stream=True,
                 stream_events=stream_events,
                 **kwargs,
             ):  # type: ignore
                 # Handle the new event types
                 if isinstance(response, WorkflowStartedEvent):
+                    workflow_started = True
                     status.update("Workflow started...")
                     if is_callable_function:
                         current_step_name = "Custom Function"
                         current_step_index = 0
                     live_log.update(status)
 
+                elif isinstance(response, WorkflowAgentStartedEvent):
+                    # Workflow agent is starting to process
+                    status.update("Workflow agent processing...")
+                    live_log.update(status)
+                    continue
+
+                elif isinstance(response, WorkflowAgentCompletedEvent):
+                    # Workflow agent has completed
+                    status.update("Workflow agent completed")
+                    live_log.update(status)
+                    continue
+
                 elif isinstance(response, StepStartedEvent):
                     step_name = response.step_name or "Unknown"
                     step_index = response.step_index or 0  # type: ignore
@@ -638,8 +672,23 @@ def print_response_stream(
                 elif isinstance(response, WorkflowCompletedEvent):
                     status.update("Workflow completed!")
 
+                    # Check if this is an agent direct response
+                    if response.metadata and response.metadata.get("agent_direct_response"):
+                        is_workflow_agent_response = True
+                        # Print the agent's direct response from history
+                        if show_step_details:
+                            live_log.update(status, refresh=True)
+                            agent_response_panel = create_panel(
+                                content=Markdown(str(response.content)) if markdown else str(response.content),
+                                title="Workflow Agent Response",
+                                border_style="green",
+                            )
+                            console.print(agent_response_panel)  # type: ignore
+                            step_started_printed = True
                     # For callable functions, print the final content block here since there are no step events
-                    if is_callable_function and show_step_details and current_step_content and not step_started_printed:
+                    elif (
+                        is_callable_function and show_step_details and current_step_content and not step_started_printed
+                    ):
                         final_step_panel = create_panel(
                             content=Markdown(current_step_content) if markdown else current_step_content,
                             title="Custom Function (Completed)",
@@ -650,8 +699,8 @@ def print_response_stream(
 
                     live_log.update(status, refresh=True)
 
-                    # Show final summary
-                    if response.metadata:
+                    # Show final summary (skip for agent responses)
+                    if response.metadata and not is_workflow_agent_response:
                         status = response.status
                         summary_content = ""
                         summary_content += f"""\n\n**Status:** {status}"""
@@ -702,8 +751,16 @@ def print_response_stream(
                                 and response.content_type != ""
                             )
                             response_str = response.content  # type: ignore
+
+                            if isinstance(response, RunContentEvent) and not workflow_started:
+                                is_workflow_agent_response = True
+                                continue
+
                         elif isinstance(response, RunContentEvent) and current_step_executor_type != "team":
                             response_str = response.content  # type: ignore
+                            # If we get RunContentEvent BEFORE workflow starts, it's an agent direct response
+                            if not workflow_started and not is_workflow_agent_response:
+                                is_workflow_agent_response = True
                         else:
                             continue
 
@@ -726,8 +783,8 @@ def print_response_stream(
                         else:
                             current_step_content += response_str
 
-                        # Live update the step panel with streaming content
-                        if show_step_details and not step_started_printed:
+                        # Live update the step panel with streaming content (skip for workflow agent responses)
+                        if show_step_details and not step_started_printed and not is_workflow_agent_response:
                             # Generate smart step number for streaming title (will use cached value)
                             step_display = get_step_display_number(current_step_index, current_step_name)
                             title = f"{step_display}: {current_step_name} (Streaming...)"
@@ -749,8 +806,8 @@ def print_response_stream(
 
             live_log.update("")
 
-            # Final completion message
-            if show_time:
+            # Final completion message (skip for agent responses)
+            if show_time and not is_workflow_agent_response:
                 completion_text = Text(f"Completed in {response_timer.elapsed:.1f}s", style="bold green")
                 console.print(completion_text)  # type: ignore
 
@@ -832,6 +889,7 @@ async def aprint_response(
     audio: Optional[List[Audio]] = None,
     images: Optional[List[Image]] = None,
     videos: Optional[List[Video]] = None,
+    files: Optional[List[File]] = None,
     markdown: bool = True,
     show_time: bool = True,
     show_step_details: bool = True,
@@ -860,6 +918,8 @@ async def aprint_response(
         media_info.append(f"Images: {len(images)}")
     if videos:
         media_info.append(f"Videos: {len(videos)}")
+    if files:
+        media_info.append(f"Files: {len(files)}")
 
     workflow_info = f"""**Workflow:** {workflow.name}"""
     if workflow.description:
@@ -910,12 +970,22 @@ async def aprint_response(
                 audio=audio,
                 images=images,
                 videos=videos,
+                files=files,
                 **kwargs,
             )  # type: ignore
 
             response_timer.stop()
 
-            if show_step_details and workflow_response.step_results:
+            # Check if this is a workflow agent direct response
+            if workflow_response.workflow_agent_run is not None and not workflow_response.workflow_agent_run.tools:
+                # Agent answered directly from history without executing workflow
+                agent_response_panel = create_panel(
+                    content=Markdown(str(workflow_response.content)) if markdown else str(workflow_response.content),
+                    title="Workflow Agent Response",
+                    border_style="green",
+                )
+                console.print(agent_response_panel)  # type: ignore
+            elif show_step_details and workflow_response.step_results:
                 for i, step_output in enumerate(workflow_response.step_results):
                     print_step_output_recursive(step_output, i + 1, markdown, console)  # type: ignore
 
@@ -970,6 +1040,7 @@ async def aprint_response_stream(
     audio: Optional[List[Audio]] = None,
     images: Optional[List[Image]] = None,
     videos: Optional[List[Video]] = None,
+    files: Optional[List[File]] = None,
     stream_events: bool = False,
     stream_intermediate_steps: bool = False,
     markdown: bool = True,
@@ -994,6 +1065,8 @@ async def aprint_response_stream(
         media_info.append(f"Images: {len(images)}")
     if videos:
         media_info.append(f"Videos: {len(videos)}")
+    if files:
+        media_info.append(f"Files: {len(files)}")
 
     workflow_info = f"""**Workflow:** {workflow.name}"""
     if workflow.description:
@@ -1037,6 +1110,8 @@ async def aprint_response_stream(
     step_results = []
     step_started_printed = False
     is_callable_function = callable(workflow.steps)
+    workflow_started = False  # Track if workflow has actually started
+    is_workflow_agent_response = False  # Track if this is a workflow agent direct response
 
     # Smart step hierarchy tracking
     current_primitive_context = None  # Current primitive being executed (parallel, loop, etc.)
@@ -1098,19 +1173,37 @@ async def aprint_response_stream(
                 audio=audio,
                 images=images,
                 videos=videos,
+                files=files,
                 stream=True,
                 stream_events=stream_events,
                 **kwargs,
             ):  # type: ignore
                 # Handle the new event types
                 if isinstance(response, WorkflowStartedEvent):
+                    workflow_started = True
                     status.update("Workflow started...")
                     if is_callable_function:
                         current_step_name = "Custom Function"
                         current_step_index = 0
                     live_log.update(status)
 
+                elif isinstance(response, WorkflowAgentStartedEvent):
+                    # Workflow agent is starting to process
+                    status.update("Workflow agent processing...")
+                    live_log.update(status)
+                    continue
+
+                elif isinstance(response, WorkflowAgentCompletedEvent):
+                    # Workflow agent has completed
+                    status.update("Workflow agent completed")
+                    live_log.update(status)
+                    continue
+
                 elif isinstance(response, StepStartedEvent):
+                    # Skip step events if workflow hasn't started (agent direct response)
+                    if not workflow_started:
+                        continue
+
                     step_name = response.step_name or "Unknown"
                     step_index = response.step_index or 0  # type: ignore
 
@@ -1422,8 +1515,23 @@ async def aprint_response_stream(
                 elif isinstance(response, WorkflowCompletedEvent):
                     status.update("Workflow completed!")
 
+                    # Check if this is an agent direct response
+                    if response.metadata and response.metadata.get("agent_direct_response"):
+                        is_workflow_agent_response = True
+                        # Print the agent's direct response from history
+                        if show_step_details:
+                            live_log.update(status, refresh=True)
+                            agent_response_panel = create_panel(
+                                content=Markdown(str(response.content)) if markdown else str(response.content),
+                                title="Workflow Agent Response",
+                                border_style="green",
+                            )
+                            console.print(agent_response_panel)  # type: ignore
+                            step_started_printed = True
                     # For callable functions, print the final content block here since there are no step events
-                    if is_callable_function and show_step_details and current_step_content and not step_started_printed:
+                    elif (
+                        is_callable_function and show_step_details and current_step_content and not step_started_printed
+                    ):
                         final_step_panel = create_panel(
                             content=Markdown(current_step_content) if markdown else current_step_content,
                             title="Custom Function (Completed)",
@@ -1434,8 +1542,8 @@ async def aprint_response_stream(
 
                     live_log.update(status, refresh=True)
 
-                    # Show final summary
-                    if response.metadata:
+                    # Show final summary (skip for agent responses)
+                    if response.metadata and not is_workflow_agent_response:
                         status = response.status
                         summary_content = ""
                         summary_content += f"""\n\n**Status:** {status}"""
@@ -1483,6 +1591,11 @@ async def aprint_response_stream(
                                 # Extract the content from the streaming event
                                 response_str = response.content  # type: ignore
 
+                                # If we get RunContentEvent BEFORE workflow starts, it's an agent direct response
+                                if isinstance(response, RunContentEvent) and not workflow_started:
+                                    is_workflow_agent_response = True
+                                    continue  # Skip ALL agent direct response content
+
                                 # Check if this is a team's final structured output
                                 is_structured_output = (
                                     isinstance(response, TeamRunContentEvent)
@@ -1492,6 +1605,9 @@ async def aprint_response_stream(
                                 )
                         elif isinstance(response, RunContentEvent) and current_step_executor_type != "team":
                             response_str = response.content  # type: ignore
+                            # If we get RunContentEvent BEFORE workflow starts, it's an agent direct response
+                            if not workflow_started and not is_workflow_agent_response:
+                                is_workflow_agent_response = True
                         else:
                             continue
 
@@ -1514,8 +1630,8 @@ async def aprint_response_stream(
                         else:
                             current_step_content += response_str
 
-                        # Live update the step panel with streaming content
-                        if show_step_details and not step_started_printed:
+                        # Live update the step panel with streaming content (skip for workflow agent responses)
+                        if show_step_details and not step_started_printed and not is_workflow_agent_response:
                             # Generate smart step number for streaming title (will use cached value)
                             step_display = get_step_display_number(current_step_index, current_step_name)
                             title = f"{step_display}: {current_step_name} (Streaming...)"
@@ -1537,8 +1653,7 @@ async def aprint_response_stream(
 
             live_log.update("")
 
-            # Final completion message
-            if show_time:
+            if show_time and not is_workflow_agent_response:
                 completion_text = Text(f"Completed in {response_timer.elapsed:.1f}s", style="bold green")
                 console.print(completion_text)  # type: ignore
 
