@@ -2,11 +2,28 @@ from abc import ABC, abstractmethod
 from typing import Any, Dict, List, Optional
 
 from agno.knowledge.document import Document
+from agno.utils.string import generate_id
 
 
 class VectorDb(ABC):
     """Base class for Vector Databases"""
 
+    def __init__(self, *, id: Optional[str] = None, name: Optional[str] = None, description: Optional[str] = None):
+        """Initialize base VectorDb.
+
+        Args:
+            id: Optional custom ID. If not provided, an id will be generated.
+            name: Optional name for the vector database.
+            description: Optional description for the vector database.
+        """
+        if name is None:
+            name = self.__class__.__name__
+
+        self.name = name
+        self.description = description
+        # Last resort fallback to generate id from name if ID not specified
+        self.id = id if id else generate_id(name)
+
     @abstractmethod
     def create(self) -> None:
         raise NotImplementedError
@@ -106,3 +123,7 @@ class VectorDb(ABC):
     @abstractmethod
     def delete_by_content_id(self, content_id: str) -> bool:
         raise NotImplementedError
+
+    @abstractmethod
+    def get_supported_search_types(self) -> List[str]:
+        raise NotImplementedError
